@@ -115,10 +115,7 @@ void personal_ip_address_write_settings (PersonalIpAddress *self)
 	gchar *fileData;
 	FILE *iniFile;
 	gsize size;
-	GtkTreeIter iter;
-	gboolean exists;
 	gchar *filename;
-	gint i=0;
 	
 	keyFile = g_key_file_new();
 		
@@ -177,7 +174,9 @@ void personal_ip_address_content_create (PersonalIpAddress *self)
 	if (gtk_icon_theme_has_icon (theme, "personal-ip-address")) {
 		self->priv->ipImage = gtk_image_new_from_icon_name ("personal-ip-address", GTK_ICON_SIZE_BUTTON);
 	} else {
-		self->priv->ipImage = gtk_image_new_from_file ("/usr/share/icons/hicolor/64x64/hildon/personal-ip-address.png");
+		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale ("/usr/share/icons/hicolor/64x64/hildon/personal-ip-address.png", 58, 58, TRUE, NULL);
+		self->priv->ipImage = gtk_image_new_from_pixbuf (pixbuf);
+		g_object_unref (pixbuf);
 	}
 	self->priv->ipLabel = gtk_label_new ("IP");
 	GtkWidget *box = gtk_hbox_new (FALSE, 0);
